==========
redgettext
==========
A slightly modified version of pygettext for `Cog-Creators/Red-DiscordBot
<https://github.com/Cog-Creators/Red-DiscordBot/>`_.

Installation
============
::

    pip install redgettext

Usage
=====

Extract strings surrounded with ``_()``::

    redgettext <inputfile> ...

Extract strings as well as command and cog docstrings::

    redgettext -D <inputfile> ...

For more options, do::

    redgettext -h

Copyright
=========

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
2012, 2013, 2014, 2015, 2016, 2017 Python Software Foundation. All rights reserved.
